<?php
//---------------------------------------------------------------------------------------------------
// Proyecto: Icasus (http://wiki.us.es/icasus/)
// Archivo: clase_indicador.php
// Tipo: definicion de clase
// Desarrolladores: Juanan Ruiz (juanan@us.es)
//---------------------------------------------------------------------------------------------------
// Descripcion: Gestiona los indicadores 
//---------------------------------------------------------------------------------------------------

class indicador {
   //----------------------------------------------------------------
   //Propiedades de la clase
   //----------------------------------------------------------------
   //Parametros del indicador 
   var $id_indicador;
   var $datos = array(); //almacena los datos del indicador
   var $database;
   var $error; //recoge los errores internos, solo sirve para debug
   
   //----------------------------------------------------------------
   //Metodos de la clase
   //----------------------------------------------------------------

	// Constructor de la clase
	function indicador ($database) 
	{
		$this->database = $database;
	}
   
	//Graba un nuevo indicador en la base de datos comprobando duplicados
	function crear ($id_entidad,$id_proceso,$codigo,$nombre,$umbral,$objetivo,$descripcion,$id_dimension,$formulacion,$fuente,
					$periodicidad,$id_responsable) 
	{
		//Comprueba que el nombre del indicador no este duplicado para esta entidad
		$consulta = "SELECT * FROM indicador WHERE (nombre='$nombre' OR codigo='$codigo') AND id_entidad=$id_entidad";
		$this->database->ejecutar_consulta($consulta); 
		//Si la consulta viene llena devuelve un error
		if ($this->database->obtener_fila()) 
		{
            $this->error = 'El nombre o el código del indicador ya existe para esta entidad';
            return false;
		}	 
		else
		{ 
		  //Ahora ya puedo grabar en la base de datos
		  $consulta = "INSERT INTO indicador (id_entidad,id_proceso,codigo,nombre,umbral,objetivo,descripcion,id_dimension,
					formulacion,fuente,periodicidad,id_responsable) 
					VALUES ($id_entidad,$id_proceso,'$codigo','$nombre','$umbral','$objetivo','$descripcion',$id_dimension,'$formulacion',
					'$fuente','$periodicidad',$id_responsable)";
		  $this->database->ejecutar_consulta($consulta); 
		  $this->id_indicador = $this->database->obtener_ultima_id();
		  return $this->id_indicador;
		}
	}	   

	// Obtiene los datos de un indicador, los devuelve en forma de array y los almacena en la propiedad $datos
   function obtener_datos($id_indicador)
   {
	  $consulta = 'SELECT id_indicador, i.id_entidad as id_entidad, i.nombre as nombre, descripcion, 
		i.codigo as codigo, e.nombre as entidad, i.id_dimension as id_dimension, d.nombre as dimension, 
		formulacion, fuente, umbral, objetivo, periodicidad, i.id_responsable as id_responsable,
		u.nombre as nombre_responsable, u.apellidos as apellidos_responsable, 
		p.id_proceso as id_proceso, p.nombre as proceso
		FROM indicador i 
		INNER JOIN entidad e ON i.id_entidad = e.id_entidad
		INNER JOIN usuario u ON i.id_responsable = u.id_usuario 
		INNER JOIN proceso p ON i.id_proceso = p.id_proceso 
		LEFT JOIN dimension d ON i.id_dimension = d.id_dimension 
		WHERE id_indicador=' . $id_indicador;
	  $this->database->ejecutar_consulta($consulta);
	  if ($this->database->filas_implicadas > 0) 
	  {
			$this->database->obtener_fila();
			$this->datos = $this->database->fila;
			return $this->datos;
	  }   
	  else 
	  {
      	$this->error = "No se encuentra ningun indicador con este identificador";
        return false;
      }
   }
   
	// Actualiza en la base de datos los datos del indicador que estamos editando
	function modificar($codigo, $nombre, $umbral, $objetivo, $descripcion, $formulacion, $fuente, $periodicidad,
		$id_responsable,$id_indicador,$id_proceso,$id_dimension) 
	{
		$consulta = "UPDATE indicador SET nombre='$nombre',
		  codigo = '$codigo',		
		  id_proceso = $id_proceso,	
		  descripcion = '$descripcion',
		  id_dimension = $id_dimension,
		  fuente = '$fuente',
		  formulacion = '$formulacion',
		  periodicidad = '$periodicidad',
		  umbral = '$umbral',
		  objetivo = '$objetivo',
		  id_responsable = $id_responsable
		  WHERE id_indicador = $id_indicador";
	  if ($this->database->ejecutar_consulta($consulta)) 
	  {
         return true;
	  }
	  else 
	  {
		$this->error = "No se ha podido actualizar el indicador";
        return false;
	  }
    }

    //Lista los valores recogidos para un indicador
	function listar_valores($id_indicador) 
	{
        $valores = array();
		$consulta = "SELECT * FROM valor WHERE id_indicador = $id_indicador ORDER BY fecha_recogida";
		$this->database->ejecutar_consulta($consulta);
		if ($this->database->filas_implicadas > 0) 
		{
			while ($this->database->obtener_fila()) 
			{
				$valores[] = $this->database->fila;
			}
			return $valores;
		}
		else
		{
			return false;
		}
	}

	// Borra un indicador de la base de datos, comprueba antes que no tenga valores asociados
	function borrar($id_indicador)
	{
		$consulta = "SELECT * FROM valor WHERE id_indicador = $id_indicador";

		$this->database->ejecutar_consulta($consulta);
		if ($this->database->filas_implicadas > 0) 
		{
			$this->error = 'No se puede borrar un indicador con valores asociados, borre antes los valores.';
			return false;
		}
		else
		{
			$consulta = "DELETE FROM indicador WHERE id_indicador = $id_indicador";
			$this->database->ejecutar_consulta($consulta);
			return true;
		}
	}

   // Devuelve la lista de dimensiones de calidad definidas en la base de datos
   function listar_dimensiones()
   {
		$dimensiones = array();
		$consulta = 'SELECT * FROM dimension ORDER BY nombre';
		$this->database->ejecutar_consulta($consulta);
		while ($this->database->obtener_fila())
		{
			$dimensiones[] = $this->database->fila;
		}	
		return $dimensiones;		
   }

}      
?>
