<?php
//-----------------------------------------------------------------------------------
// Proyecto: Icasus (http://wiki.us.es/icasus/)
// Archivo: class/usuario.php
// Desarrolladores: Juanan Ruiz (juanan@us.es), Jesús Martín Corredera (jjmc@us.es)
//-----------------------------------------------------------------------------------
// Descripcion:  
// Gestiona el inicio de sesión, graba los datos de un nuevo usuario
// en la base de datos y almacena los datos del usuario que accede a la aplicacion.
//-----------------------------------------------------------------------------------

class usuario 
{
	var $id_usuario;
	var $datos = array();
	var $entidades = array();
	var $error;
	var $database;
	
	function usuario($database) 
	{
		$this->database = $database;
	}

	//Busca los datos de un usuario en la base de datos en funcion de su identificador
	function obtener_datos ($id_usuario) 
	{
		$consulta = "SELECT id_usuario, login, clave, nombre, apellidos, nif, correo, telefono FROM usuario WHERE id_usuario=" . $id_usuario;
		$this->database->ejecutar_consulta($consulta);
		if ($this->database->filas_implicadas > 0) 
		{
		    $this->database->obtener_fila();
			$this->datos = $this->database->fila;
			$this->id_usuario = $id_usuario;
			return $this->datos;
		}
		else 
		{
			$this->error = "ERROR: No se encuentra el usuario en la base de datos";
			return false;
		}
	}

	// Devuelve una lista de todos los usuarios del sistema en base  a un criterio
	function listar($criterio) 
	{
		$lista_usuarios = array();
		$consulta = "SELECT * FROM usuario $criterio ORDER BY login";
		$this->database->ejecutar_consulta($consulta);
		while ($this->database->obtener_fila()) 
		{
			$lista_usuarios[] = $this->database->fila;
	    }   
		return $lista_usuarios;
	}


	//Devuelve un array con los identificadores de entidades a las que pertenece este usuario y los roles asociados
	//  rol 1 - responsable
	//  rol 2 - miembro
	//  rol 3 - asesor
	//  Se pordrán definir más roles en la base de datos
	function obtener_entidades($id_usuario) 
	{
		$consulta = "SELECT e.id_entidad as id_entidad, e.nombre as nombre_entidad, r.nombre as rol
				FROM usuario_entidad ue INNER JOIN entidad e ON ue.id_entidad = e.id_entidad
				INNER JOIN rol r ON r.id_rol = ue.id_rol 
				WHERE ue.id_usuario=$id_usuario ORDER BY nombre_entidad";
		$this->database->ejecutar_consulta($consulta);
		if ($this->database->filas_implicadas > 0) 
		{
			while ($this->database->obtener_fila()) 
			{
			    $datos = $this->database->fila;
                $identificador = $datos["id_entidad"];
				$this->entidades[$identificador] = array("id_entidad"=>$identificador,
					"nombre"=> $datos["nombre_entidad"],"rol"=> $datos["rol"]);
			}
			return $this->entidades;
			
		}
		else
	   	{
			$this->error = "AVISO: este usuario no tiene entidades asignadas";
			return false;
		}
	}
	
	//Comprueba login y clave, devuelve el identificador del usuario
	function comprobar_login($login,$clave) 
	{
		$consulta = "SELECT id_usuario FROM usuario WHERE login='$login' AND clave='$clave'";
	
		$this->database->ejecutar_consulta($consulta);
		if ($this->database->filas_implicadas > 0)
	   	{
			$this->database->obtener_fila();
			$id_usuario = $this->database->fila["id_usuario"];
			return $id_usuario;
		}
		else 
		{
			$this->error = "El nombre de usuario o la clave son incorrectos.";
			return false;
		}
		
	}
		
	//Escribe los datos de un nuevo usuario en la base de datos
	function crear ($login, $clave, $nombre, $apellidos, $nif, $correo, $telefono)
   	{
		//Comprueba que no exista un usuario con el mismo login en el sistema
		$consulta = "SELECT * FROM usuario WHERE login='$login'";

		$this->database->ejecutar_consulta($consulta);
		if ($this->database->filas_implicadas > 0) 
		{
			$this->error = "El login '$login' está duplicado en el sistema";
			return false;
		}
		
		//Comprueba que no exista un usuario con el mismo nif en el sistema
		$consulta = "SELECT * FROM usuario WHERE nif='$nif'";

		$this->database->ejecutar_consulta($consulta);
		if ($this->database->filas_implicadas > 0) 
		{
			$this->error = "El nif '$nif' está duplicado en el sistema";
			return false;
		}
		
	    //Grabamos el nuevo usuario en la base de datos
		$consulta = "INSERT INTO usuario (nombre,apellidos,nif,login,clave,correo, telefono)  
			VALUES ('$nombre','$apellidos','$nif','$login','$clave','$correo','$telefono')";

		$this->database->ejecutar_consulta($consulta);
		
		if ($this->database->filas_implicadas > 0)
		{
			//Obtenemos el identificador del nuevo usuario
			$this->id_usuario = $this->database->obtener_ultima_id();
			/*//Grabamos las entidad que se le ha asignado
			$consulta = "INSERT INTO usuario_entidad (id_usuario, id_entidad, id_rol) ";
			$consulta .= "VALUES (" . $this->id_usuario . "," . $id_entidad . ",'" . $id_rol ."')";
			$this->database->ejecutar_consulta($consulta);
        
			if ($this->database->filas_implicadas>0) 
			{ 
				$this->entidades[] = $id_entidad;
			}
			*/			
			return $this->id_usuario;
		}
		else 
		{
			$this->error = "No ha podido grabarse el nuevo usuario en el sistema.";
			return false;
		}
	}

	// Actualiza los datos de un usuario existente en la base de datos
	function modificar($id_usuario,$nombre,$apellidos,$nif,$correo,$telefono,$login,$clave) 
	{	
		//Comprueba que no exista un usuario con el mismo nif en el sistema
		$consulta = "SELECT * FROM usuario WHERE nif='" . $nif . "' AND id_usuario <> " . $id_usuario ;
		$this->database->ejecutar_consulta($consulta);
		if ($this->database->filas_implicadas > 0) {
			$this->error = "El nif '" . $nif . "' está duplicado en el sistema";
			return false;
			}
		// Modificamos los datos relativos al usuario
      	$consulta = "UPDATE usuario SET login='$login', clave='$clave',
			nombre='$nombre', apellidos='$apellidos', nif='$nif',
			correo='$correo', telefono='$telefono' WHERE id_usuario = $id_usuario";
      
		$this->database->ejecutar_consulta($consulta);
       	return true;
	}
	
	// Comprueba si los permisos del usuario son suficientes para acceder a una página
	function autorizar($page,$id_entidad,$id_usuario)
	{
		//$consulta = "SELECT * FROM permiso 
		//	WHERE (page='$page' AND id_objeto=$id_objeto AND id_usuario=$id_usuario)"; 
		switch ($page)
		{
		case 'proceso_crear':
		case 'proceso_editar':
		case 'usuario_crear':
		case 'usuario_editar':
		case 'usuario_borrar':	
		case 'indicador_crear':	
		case 'indicador_editar':	
		case 'indicador_borrar':	
		case 'entidad_crear':	
		case 'entidad_editar':	
		case 'entidad_borrar':	
		case 'entidad_poblar':	
		case 'entidad_despoblar':	
			// Mira si el usuario es administrador de la entidad en cuestión o de la entidad administrativa (id_entidad=1)
			$consulta = "SELECT * FROM usuario_entidad WHERE (id_entidad=$id_entidad OR id_entidad=1) 
				AND id_usuario=$id_usuario AND id_rol=1";
			break;
		case 'indicador_datos':
		case 'indicador_cmi':
		case 'valor_editar':
		case 'valor_crear':
		case 'valor_borrar':
			// Mira si el usuario es miembro de la entidad en cuestión o de la entidad administrativa (id_entidad=1)
			$consulta = "SELECT * FROM usuario_entidad WHERE (id_entidad=$id_entidad OR id_entidad=1) AND id_usuario=$id_usuario";
			break;
		default:
			$consulta = "SELECT 1";
		}
		$this->database->ejecutar_consulta($consulta);
		//echo $consulta;
		if ($this->database->filas_implicadas > 0) 
		{
			return true;
		}
		else
		{
			return false;
		}
	}

	function borrar($id_usuario)
	{
		$this->error = false;
		// Comprueba que el usuario no pertenece a ninguna entidad
		$consulta = "SELECT * FROM usuario_entidad WHERE id_usuario=$id_usuario";
		$this->database->ejecutar_consulta($consulta);
		if ($this->database->filas_implicadas > 0)
		{
			$this->error = 'No se puede borrar un usuario mientras pertenezca a alguna entidad'; 
		}
		// Comprueba que el usuario no es responsable de ningún indicador
		$consulta = "SELECT id_indicador FROM indicador WHERE id_responsable=$id_usuario";
		$this->database->ejecutar_consulta($consulta);
		if ($this->database->filas_implicadas > 0)
		{
			$this->error = 'No se puede borrar un usuario con indicadores a su cargo'; 
		}
		// Si hubo algún error no borra
		if ($this->error)
		{
			return false;
		}
		else
		{
			// No hay error, intenta borrar
			$consulta = "DELETE FROM usuario WHERE id_usuario=$id_usuario";
			$this->database->ejecutar_consulta($consulta);
			if ($this->database->filas_implicadas > 0)
			{
				return true;
			}
			else
			{
				$this->error = 'No se pudo borrar el usuario por alguna causa desconocida';
				return false;
			}
		}	
	}
}
?>
